<?php
/**
 * japanese language file
 * @author Yuji Takenaka <webmaster@davilin.com>
 * @author Chris Smith <chris@jalakai.co.uk>
 * @author Ikuo Obataya <i.obataya@gmail.com>
 * @author Daniel Dupriest <kououken@gmail.com>
 * @author Kazutaka Miyasaka <kazmiya@gmail.com>
 * @author Taisuke Shimamoto <dentostar@gmail.com>
 * @author Satoshi Sahara <sahara.satoshi@gmail.com>
 */
$lang['menu']                  = 'ユーザー管理';
$lang['noauth']                = '（ユーザー認証が無効です）';
$lang['nosupport']             = '（ユーザー管理はサポートされていません）';
$lang['badauth']               = '認証のメカニズムが無効です';
$lang['user_id']               = 'ユーザー';
$lang['user_pass']             = 'パスワード';
$lang['user_name']             = '氏名';
$lang['user_mail']             = 'メールアドレス';
$lang['user_groups']           = 'グループ';
$lang['field']                 = '項目';
$lang['value']                 = '値';
$lang['add']                   = '追加';
$lang['delete']                = '削除';
$lang['delete_selected']       = '選択したユーザーを削除';
$lang['edit']                  = '編集';
$lang['edit_prompt']           = 'このユーザーを編集';
$lang['modify']                = '変更を保存';
$lang['search']                = '検索';
$lang['search_prompt']         = '検索を実行';
$lang['clear']                 = '検索フィルターをリセット';
$lang['filter']                = 'フィルター';
$lang['summary']               = 'ユーザー %1$d-%2$d / %3$d, 総ユーザー数 %4$d';
$lang['nonefound']             = 'ユーザーが見つかりません, 総ユーザー数 %d';
$lang['delete_ok']             = '%d ユーザーが削除されました';
$lang['delete_fail']           = '%d ユーザーの削除に失敗しました';
$lang['update_ok']             = 'ユーザーは更新されました';
$lang['update_fail']           = 'ユーザーの更新に失敗しました';
$lang['update_exists']         = 'ユーザー名（%s）は既に存在するため、ユーザー名の変更に失敗しました（その他の項目は変更されました）。';
$lang['start']                 = '最初';
$lang['prev']                  = '前へ';
$lang['next']                  = '次へ';
$lang['last']                  = '最後';
$lang['edit_usermissing']      = '選択したユーザーは見つかりません。削除もしくは変更された可能性があります。';
$lang['user_notify']           = 'ユーザーに通知する';
$lang['note_notify']           = '通知メールは、ユーザーに新たなパスワードが設定された場合のみ送信されます。';
$lang['note_group']            = 'グループを指定しない場合は、既定のグループ（%s）に配属されます。';
$lang['note_pass']             = 'パスワードを空欄とした場合は、（”ユーザーに通知する”がチェックされていなくとも）自動生成したパスワードの通知がユーザー宛てに送信されます。';
$lang['add_ok']                = 'ユーザーを登録しました';
$lang['add_fail']              = 'ユーザーの登録に失敗しました';
$lang['notify_ok']             = '通知メールを送信しました';
$lang['notify_fail']           = '通知メールを送信できませんでした';
